@@ -892,7 +892,7 @@ int msOGRWriteFromQuery( mapObj *map, outputFormatObj *format, int sendheaders )
   /*      Process each layer with a resultset.                            */
   /* ==================================================================== */
   for( iLayer = 0; iLayer < map->numlayers; iLayer++ ) {
-    int status;
+    int status = 0;
     layerObj *layer = GET_LAYER(map, iLayer);
     shapeObj resultshape;
     OGRLayerH hOGRLayer;
@@ -1103,20 +1103,21 @@ int msOGRWriteFromQuery( mapObj *map, outputFormatObj *format, int sendheaders )
       if( layer->resultcache->results[i].shape )
       {
           /* msDebug("Using cached shape %ld\n", layer->resultcache->results[i].shapeindex); */
-          msCopyShape(layer->resultcache->results[i].shape, &resultshape);
+          status = msCopyShape(layer->resultcache->results[i].shape, &resultshape);
       }
       else
       {
-        status = msLayerGetShape(layer, &resultshape, &(layer->resultcache->results[i]));
-        if(status != MS_SUCCESS) {
-            OGR_DS_Destroy( hDS );
-            msOGRCleanupDS( datasource_name );
-            msGMLFreeItems(item_list);
-            msFreeShape(&resultshape);
-            CSLDestroy(layer_options);
-            return status;
-        }
+          status = msLayerGetShape(layer, &resultshape, &(layer->resultcache->results[i]));
       }
+      
+      if(status != MS_SUCCESS) {
+          OGR_DS_Destroy( hDS );
+          msOGRCleanupDS( datasource_name );
+          msGMLFreeItems(item_list);
+          msFreeShape(&resultshape);
+          CSLDestroy(layer_options);
+          return status;
+      }      
 
       /*
       ** Perform classification, and some annotation related magic.
