@@ -417,6 +417,9 @@ msRasterQueryByRectLow(mapObj *map, layerObj *layer, GDALDatasetH hDS,
   CPLErr      eErr;
   rasterLayerInfo *rlinfo;
   rectObj     searchrect;
+#if PROJ_VERSION_MAJOR < 6
+  int         mayNeedLonWrapAdjustment = MS_FALSE;
+#endif
 
   rlinfo = (rasterLayerInfo *) layer->layerinfo;
 
@@ -555,6 +558,16 @@ msRasterQueryByRectLow(mapObj *map, layerObj *layer, GDALDatasetH hDS,
     + sqrt( rlinfo->range_dist );
   dfAdjustedRange = dfAdjustedRange * dfAdjustedRange;
 
+#if PROJ_VERSION_MAJOR < 6
+    if( layer->project &&
+        pj_is_latlong(layer->projection.proj) &&
+        pj_is_latlong(map->projection.proj) )
+    {
+        double dfLonWrap = 0;
+        mayNeedLonWrapAdjustment = msProjectHasLonWrap(&(layer->projection), &dfLonWrap);
+    }
+#endif
+
   /* -------------------------------------------------------------------- */
   /*      Loop over all pixels determining which are "in".                */
   /* -------------------------------------------------------------------- */
@@ -580,8 +593,22 @@ msRasterQueryByRectLow(mapObj *map, layerObj *layer, GDALDatasetH hDS,
       /* coordinates if we have a hit */
       sReprojectedPixelLocation = sPixelLocation;
       if( layer->project )
+      {
+#if PROJ_VERSION_MAJOR < 6
+        /* Works around a bug in PROJ < 6 when reprojecting from a lon_wrap */
+        /* geogCRS to a geogCRS, and the input abs(longitude) is > 180. Then */
+        /* lon_wrap was ignored and the output longitude remained as the source */
+        if( mayNeedLonWrapAdjustment )
+        {
+            if( rlinfo->target_point.x < sReprojectedPixelLocation.x - 180 )
+                sReprojectedPixelLocation.x -= 360;
+            else if( rlinfo->target_point.x > sReprojectedPixelLocation.x + 180 )
+                sReprojectedPixelLocation.x += 360;
+        }
+#endif
         msProjectPoint( &(layer->projection), &(map->projection),
                         &sReprojectedPixelLocation);
+      }
 
       /* If we are doing QueryByShape, check against the shape now */
       if( rlinfo->searchshape != NULL ) {
